@@ -32,9 +32,11 @@ describe 'basic manila' do
       class { 'manila::logging':
         debug => true,
       }
+      class { 'manila::db':
+        database_connection => 'mysql+pymysql://manila:a_big_secret@127.0.0.1/manila?charset=utf8',
+      }
       class { 'manila':
         default_transport_url => 'rabbit://manila:an_even_bigger_secret@127.0.0.1:5672/',
-        sql_connection        => 'mysql+pymysql://manila:a_big_secret@127.0.0.1/manila?charset=utf8',
       }
       class { 'manila::db::mysql':
         password => 'a_big_secret',
@@ -61,6 +63,9 @@ describe 'basic manila' do
       class { 'manila::cron::db_purge': }
 
       # missing: backends, share, service_instance
+
+      manila_type { 'sharetype':
+      }
       EOS
 
 
