@@ -16,6 +16,8 @@ describe 'manila::db::postgresql' do
         req_params
       end
 
+      it { is_expected.to contain_class('manila::deps') }
+
       it { is_expected.to contain_openstacklib__db__postgresql('manila').with(
         :user       => 'manila',
         :password   => 'manilapass',
@@ -36,7 +38,10 @@ describe 'manila::db::postgresql' do
         }))
       end
 
-      it_configures 'manila::db::postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_configures 'manila::db::postgresql'
+      end
     end
   end
 
