@@ -23,6 +23,9 @@ describe 'manila::keystone::auth' do
         :password            => 'manila_password',
         :email               => 'manila@localhost',
         :tenant              => 'services',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8786/v1/%(tenant_id)s',
         :internal_url        => 'http://127.0.0.1:8786/v1/%(tenant_id)s',
         :admin_url           => 'http://127.0.0.1:8786/v1/%(tenant_id)s',
@@ -40,6 +43,9 @@ describe 'manila::keystone::auth' do
         :password            => 'manila_password',
         :email               => 'manilav2@localhost',
         :tenant              => 'services',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8786/v2',
         :internal_url        => 'http://127.0.0.1:8786/v2',
         :admin_url           => 'http://127.0.0.1:8786/v2',
@@ -52,6 +58,9 @@ describe 'manila::keystone::auth' do
           :auth_name              => 'alt_manila',
           :email                  => 'alt_manila@alt_localhost',
           :tenant                 => 'alt_service',
+          :roles                  => ['admin', 'service'],
+          :system_scope           => 'alt_all',
+          :system_roles           => ['admin', 'member', 'reader'],
           :configure_endpoint     => false,
           :configure_user         => false,
           :configure_user_role    => false,
@@ -88,6 +97,9 @@ describe 'manila::keystone::auth' do
         :password            => 'manila_password',
         :email               => 'alt_manila@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
@@ -105,6 +117,9 @@ describe 'manila::keystone::auth' do
         :password            => 'manilav2_password',
         :email               => 'alt_manilav2@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.20:80',
         :internal_url        => 'http://10.10.10.21:81',
         :admin_url           => 'http://10.10.10.22:81',
