@@ -5,21 +5,21 @@ describe 'manila::quota' do
   shared_examples_for 'manila::quota' do
     context 'with default parameters' do
       it 'contains default values' do
-        is_expected.to contain_manila_config('quota/quota_shares').with(
+        is_expected.to contain_manila_config('quota/shares').with(
           :value => '<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('quota/quota_snapshots').with(
+        is_expected.to contain_manila_config('quota/snapshots').with(
           :value => '<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('quota/quota_gigabytes').with(
+        is_expected.to contain_manila_config('quota/gigabytes').with(
           :value => '<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('quota/quota_driver').with(
+        is_expected.to contain_manila_config('quota/driver').with(
           :value => '<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('quota/quota_snapshot_gigabytes').with(
+        is_expected.to contain_manila_config('quota/snapshot_gigabytes').with(
           :value => '<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('quota/quota_share_networks').with(
+        is_expected.to contain_manila_config('quota/share_networks').with(
           :value => '<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('quota/quota_share_replicas').with(
+        is_expected.to contain_manila_config('quota/share_replicas').with(
           :value => '<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('quota/quota_replica_gigabytes').with(
+        is_expected.to contain_manila_config('quota/replica_gigabytes').with(
           :value => '<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('quota/reservation_expire').with(
           :value => '<SERVICE DEFAULT>')
@@ -32,34 +32,34 @@ describe 'manila::quota' do
 
     context 'with overridden parameters' do
       let :params do
-        { :quota_shares             => 1000,
-          :quota_snapshots          => 1000,
-          :quota_gigabytes          => 100000,
-          :quota_driver             => 'manila.quota.DbQuotaDriver',
-          :quota_snapshot_gigabytes => 10000,
-          :quota_share_networks     => 100,
-          :quota_share_replicas     => 10,
-          :quota_replica_gigabytes  => 100,
-          :reservation_expire       => 864000,
-          :until_refresh            => 10,
-          :max_age                  => 10,}
+        { :shares             => 1000,
+          :snapshots          => 1000,
+          :gigabytes          => 100000,
+          :driver             => 'manila.quota.DbQuotaDriver',
+          :snapshot_gigabytes => 10000,
+          :share_networks     => 100,
+          :share_replicas     => 10,
+          :replica_gigabytes  => 100,
+          :reservation_expire => 864000,
+          :until_refresh      => 10,
+          :max_age            => 10,}
       end
       it 'contains overrided values' do
-        is_expected.to contain_manila_config('quota/quota_shares').with(
+        is_expected.to contain_manila_config('quota/shares').with(
           :value => 1000)
-        is_expected.to contain_manila_config('quota/quota_snapshots').with(
+        is_expected.to contain_manila_config('quota/snapshots').with(
           :value => 1000)
-        is_expected.to contain_manila_config('quota/quota_gigabytes').with(
+        is_expected.to contain_manila_config('quota/gigabytes').with(
           :value => 100000)
-        is_expected.to contain_manila_config('quota/quota_driver').with(
+        is_expected.to contain_manila_config('quota/driver').with(
           :value => 'manila.quota.DbQuotaDriver')
-        is_expected.to contain_manila_config('quota/quota_snapshot_gigabytes').with(
+        is_expected.to contain_manila_config('quota/snapshot_gigabytes').with(
           :value => 10000)
-        is_expected.to contain_manila_config('quota/quota_share_networks').with(
+        is_expected.to contain_manila_config('quota/share_networks').with(
           :value => 100)
-        is_expected.to contain_manila_config('quota/quota_share_replicas').with(
+        is_expected.to contain_manila_config('quota/share_replicas').with(
           :value => 10)
-        is_expected.to contain_manila_config('quota/quota_replica_gigabytes').with(
+        is_expected.to contain_manila_config('quota/replica_gigabytes').with(
           :value => 100)
         is_expected.to contain_manila_config('quota/reservation_expire').with(
           :value => 864000)
@@ -69,6 +69,37 @@ describe 'manila::quota' do
           :value => 10)
       end
     end
+
+    context 'with deprecated parameters' do
+      let :params do
+        { :quota_shares             => 1000,
+          :quota_snapshots          => 1000,
+          :quota_gigabytes          => 100000,
+          :quota_driver             => 'manila.quota.DbQuotaDriver',
+          :quota_snapshot_gigabytes => 10000,
+          :quota_share_networks     => 100,
+          :quota_share_replicas     => 10,
+          :quota_replica_gigabytes  => 100,}
+      end
+      it 'contains overrided values' do
+        is_expected.to contain_manila_config('quota/shares').with(
+          :value => 1000)
+        is_expected.to contain_manila_config('quota/snapshots').with(
+          :value => 1000)
+        is_expected.to contain_manila_config('quota/gigabytes').with(
+          :value => 100000)
+        is_expected.to contain_manila_config('quota/driver').with(
+          :value => 'manila.quota.DbQuotaDriver')
+        is_expected.to contain_manila_config('quota/snapshot_gigabytes').with(
+          :value => 10000)
+        is_expected.to contain_manila_config('quota/share_networks').with(
+          :value => 100)
+        is_expected.to contain_manila_config('quota/share_replicas').with(
+          :value => 10)
+        is_expected.to contain_manila_config('quota/replica_gigabytes').with(
+          :value => 100)
+      end
+    end
   end
 
   on_supported_os({
